==> foundation-2.6.1.tgz: package/Database/Database.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Database = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M32.948 24.348h-.011c-.057-2.327-1.971-4.133-4.3-4.165v-.006h-15.69v.011c-2.307.057-4.067 1.852-4.119 4.161h-.01v51.2h.008c.043 2.3 1.838 4.089 4.121 4.178v.097h15.69c2.401-.001 4.311-1.875 4.311-4.274V24.348zM20.882 74.836a6.234 6.234 0 11.001-12.467 6.234 6.234 0 01-.001 12.467zm7.078-22.41H13.805V25.164H27.96v27.262zm34.105-28.078h-.011c-.057-2.327-1.971-4.133-4.3-4.165v-.006h-15.69v.011c-2.307.057-4.067 1.852-4.119 4.161h-.01v51.2h.008c.043 2.3 1.838 4.089 4.121 4.178v.097h15.69c2.401-.001 4.311-1.875 4.311-4.274V24.348zM49.999 74.836A6.234 6.234 0 1150 62.369a6.234 6.234 0 010 12.467zm7.078-22.41H42.923V25.164h14.155v27.262zm34.105-28.078h-.011c-.057-2.327-1.971-4.133-4.3-4.165v-.006h-15.69v.011c-2.307.057-4.067 1.852-4.119 4.161h-.01v51.2h.008c.043 2.3 1.838 4.089 4.121 4.178v.097h15.69c2.401-.001 4.311-1.875 4.311-4.274V24.348zM79.117 74.836a6.234 6.234 0 11.001-12.467 6.234 6.234 0 01-.001 12.467zm7.078-22.41H72.04V25.164h14.155v27.262z"
  }));
});
Database.displayName = 'Database';
export const DatabaseDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Database/Database.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Database = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M32.948 24.348h-.011c-.057-2.327-1.971-4.133-4.3-4.165v-.006h-15.69v.011c-2.307.057-4.067 1.852-4.119 4.161h-.01v51.2h.008c.043 2.3 1.838 4.089 4.121 4.178v.097h15.69c2.401-.001 4.311-1.875 4.311-4.274V24.348zM20.882 74.836a6.234 6.234 0 11.001-12.467 6.234 6.234 0 01-.001 12.467zm7.078-22.41H13.805V25.164H27.96v27.262zm34.105-28.078h-.011c-.057-2.327-1.971-4.133-4.3-4.165v-.006h-15.69v.011c-2.307.057-4.067 1.852-4.119 4.161h-.01v51.2h.008c.043 2.3 1.838 4.089 4.121 4.178v.097h15.69c2.401-.001 4.311-1.875 4.311-4.274V24.348zM49.999 74.836A6.234 6.234 0 1150 62.369a6.234 6.234 0 010 12.467zm7.078-22.41H42.923V25.164h14.155v27.262zm34.105-28.078h-.011c-.057-2.327-1.971-4.133-4.3-4.165v-.006h-15.69v.011c-2.307.057-4.067 1.852-4.119 4.161h-.01v51.2h.008c.043 2.3 1.838 4.089 4.121 4.178v.097h15.69c2.401-.001 4.311-1.875 4.311-4.274V24.348zM79.117 74.836a6.234 6.234 0 11.001-12.467 6.234 6.234 0 01-.001 12.467zm7.078-22.41H72.04V25.164h14.155v27.262z"
  }));
});
Database.displayName = 'Database';
export var DatabaseDimensions = {
  height: 100,
  width: 100
};
